@@ -28,6 +28,26 @@
 
 press_data_type* press_data; 
 
+void create_press_data (GdkWindow * window)
+{
+  GdkWindowAttr attributes;
+
+  attributes.wclass = GDK_INPUT_OUTPUT;
+  attributes.window_type = GDK_WINDOW_CHILD;
+  attributes.event_mask = 0;
+  attributes.width = card_width;
+  attributes.height = card_height;
+  attributes.colormap = gdk_drawable_get_colormap (GDK_DRAWABLE(window));
+  attributes.visual = gdk_drawable_get_visual (GDK_DRAWABLE(window));
+  
+  press_data = g_malloc0(sizeof(press_data_type));
+  press_data->moving_cards = gdk_window_new(window, &attributes,
+					    (GDK_WA_VISUAL | GDK_WA_COLORMAP));
+  press_data->highlight_window = gdk_window_new(window, &attributes,
+                                                (GDK_WA_VISUAL | GDK_WA_COLORMAP));
+  press_data->status = 0;
+}
+
 void generate_press_data ( ) {
   GList* tempptr;
   SCM old_cards = SCM_EOL; 
@@ -37,15 +57,15 @@ void generate_press_data ( ) {
   GdkColor masked = {0, 0, 0, 0}, unmasked = {1, 65535, 65535, 65535};
 
   for (tempptr = hslot->cards; tempptr; tempptr = tempptr->next)
-    old_cards = gh_cons(make_card(tempptr->data), old_cards);
+    old_cards = scm_cons (make_card(tempptr->data), old_cards);
 
   delta = hslot->exposed - (hslot->length - press_data->cardid) - 1;
-  press_data->xoffset -= x = hslot->x + delta * hslot->dx;
-  press_data->yoffset -= y = hslot->y + delta * hslot->dy;
+  press_data->xoffset -= x = hslot->pixelx + delta * hslot->pixeldx;
+  press_data->yoffset -= y = hslot->pixely + delta * hslot->pixeldy;
 
   press_data->cards = g_list_nth(hslot->cards, press_data->cardid - 1);
-  width = get_card_width() + (hslot->length - press_data->cardid) * hslot->dx;
-  height= get_card_height() + (hslot->length - press_data->cardid) * hslot->dy;
+  width = card_width + (hslot->length - press_data->cardid) * hslot->pixeldx;
+  height= card_height + (hslot->length - press_data->cardid) * hslot->pixeldy;
   
   gdk_window_resize(press_data->moving_cards, width, height);
   gdk_window_move(press_data->moving_cards, x, y);
@@ -66,7 +86,7 @@ void generate_press_data ( ) {
   gdk_gc_set_clip_mask (gc1, mask); 
   gdk_gc_set_clip_mask (gc2, mask); 
 
-  x = y = 0; width = get_card_width(); height = get_card_height();
+  x = y = 0; width = card_width; height = card_height;
 
   for (tempptr = press_data->cards; tempptr; tempptr = tempptr->next) {
     hcard_type hcard = (hcard_type) tempptr->data; 
@@ -85,7 +105,7 @@ void generate_press_data ( ) {
     gdk_draw_rectangle (press_data->moving_mask, gc2, TRUE, 
 			x, y, width, height);
     
-    x += hslot->dx; y += hslot->dy;
+    x += hslot->pixeldx; y += hslot->pixeldy;
   }
   g_object_unref (gc1);
   g_object_unref (gc2);
@@ -96,13 +116,17 @@ void generate_press_data ( ) {
 				 press_data->moving_mask, 0, 0);
   gdk_window_show (press_data->moving_cards);
 
+  /* FIXME: We can end up here with press_data->cards = NULL.  Why?
+   * (obviously this is a crasher) It happens while dragging. It
+   * is probably also related to 121762.*/
   if (press_data->cards->prev) 
     press_data->cards->prev->next = NULL;
   else 
     hslot->cards = NULL;
 
-  gh_call2 (gh_eval_str ("record-move"), gh_long2scm (hslot->id), 
-	   old_cards);
+  scm_call_2 (scm_c_eval_string ("record-move"),
+	      scm_long2num (hslot->id), 
+	      old_cards);
 
   press_data->cards->prev = NULL;
   update_slot_length(press_data->hslot);
