@@ -95,6 +95,11 @@ gboolean move_possible_to(GtkGridBoard * gridboard, int x, int y, int turn) {
 gboolean computer_move_cb(gpointer turn) {
 	move cm;
 
+	/* In case the level gets changed between the timeout
+	 * being set and it going off. */
+	if (props_get_level (GPOINTER_TO_INT (turn)) < 1)
+	  return FALSE;
+
 	cm=computer_move(gridboard, GPOINTER_TO_INT(turn));
 	do_move(cm);
 	return FALSE;
@@ -327,6 +332,7 @@ void undo_move_cb(GtkWidget * widget, gpointer data) {
 	if (!props_is_human(turn)) {
 		g_timeout_add(timeout, computer_move_cb, GINT_TO_POINTER(turn));
 	}
+	selection.valid = FALSE;
 	appbar_set_turn (turn);
 	appbar_set_white (gtk_gridboard_count_pieces(gridboard, WHITE));
 	appbar_set_black (gtk_gridboard_count_pieces(gridboard, BLACK));
@@ -334,7 +340,8 @@ void undo_move_cb(GtkWidget * widget, gpointer data) {
 
 /* menu: Game->Quit */
 gboolean quit_game_cb(GtkWidget * widget, gpointer data) {
-        g_source_remove (timeoutid);
+        if (timeoutid)
+		g_source_remove (timeoutid);
 	gtk_main_quit();
 	
 	return TRUE;
@@ -364,44 +371,18 @@ apply_changes() {
 void
 about_cb(GtkWidget *widget, gpointer data)
 {
-  static GtkWidget *about;
-  GdkPixbuf *pixbuf = NULL;
   const gchar *authors[] = {"Chris Rogers", "Sjoerd Langkemper", 
 			    N_("Based on code from Iagno by Ian Peters"), NULL};
-  const gchar *documenters[] = { NULL };
-  const gchar *translator_credits = _("translator-credits");
-  gchar *iconfile;
 
-  if (about != NULL) {
-    gtk_window_present (GTK_WINDOW (about));
-    return;
-  }
-
-  iconfile = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-					"gataxx.png", TRUE, NULL);
-  if (iconfile != NULL) {
-    pixbuf = gdk_pixbuf_new_from_file (iconfile, NULL);
-    g_free (iconfile);
-  }
-
-  about = gnome_about_new (_("Ataxx"), VERSION,
-			   "Copyright \xc2\xa9 1999-2003 Chris Rogers\n"
-			   "Copyright \xc2\xa9 2004 Sjoerd Langkemper",
-                          _("A disk-flipping game where you attempt to dominate the board."),
-                          (const char **)authors,
-                          (const char **)documenters,
-                          g_utf8_collate (translator_credits, "translator-credits") !=
-0 ? translator_credits : NULL,
-                          pixbuf);
-
-  if (pixbuf != NULL)
-    gdk_pixbuf_unref (pixbuf);
-  
-  g_signal_connect (G_OBJECT (about), "destroy", 
-		    G_CALLBACK (gtk_widget_destroyed), &about);
-  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
-  
-  gtk_widget_show (about);
+  gtk_show_about_dialog (GTK_WINDOW (window),
+			 "name", _("Ataxx"), 
+			 "version", VERSION,
+			 "copyright", "Copyright \xc2\xa9 1999-2003 Chris Rogers\n"
+				      "Copyright \xc2\xa9 2004-2005 Sjoerd Langkemper",
+			 "comments", _("A disk-flipping game where you attempt to dominate the board."),
+			 "authors", authors,
+			 "translator_credits", _("translator-credits"),
+			 NULL);
 }
 
 
@@ -412,14 +393,6 @@ GConfClient * get_gconf_client() {
 	return gconfclient;
 }
 
-/* returns /apps/gataxx/item */ 
-char * get_gconf_uri(const char * item) {
-	static char uri[255];
-	strcpy(uri, "/apps/gataxx/");
-	strcat(uri, item);
-	return uri;
-}
-
 static gboolean save_state_cb (GnomeClient * client, gint phase, 
 			       GnomeSaveStyle style, gboolean shutdown,
 			       GnomeInteractStyle interactive, gboolean fast,
