@@ -31,18 +31,26 @@ class Preview
 public:
 	Preview();
 	
-	void show();
 	void updateSize();
-	void clear();
-	
+
 	GtkWidget * getWidget()	{return w;}
-	
+
+	void enable(bool enable);
+	void previewBlock(int bnr, int brot, int bcolor);
+
 private:
 	GtkWidget * w;
+	gint width;
+	gint height;
 
-	void paint(GdkRectangle *area);
+	int blocknr;
+	int blockrot;
+	int blockcolor;
 
-	static gint eventHandler(GtkWidget *widget, GdkEvent *event, void *d);
+	bool enabled;
+
+	static gint configure(GtkWidget * widget, GdkEventConfigure * event, Preview * preview);
+	static gint expose(GtkWidget *widget, GdkEventExpose *event, Preview * preview);
 };
 
 #endif //__preview_h__
